"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lint_1 = require("./lint");
var clangFormat = require('clang-format');
var baseArgs = ['-style', '{Language: JavaScript, BasedOnStyle: Google, ColumnLimit: 80}'];
/**
 * Run tslint fix and clang fix with the default configuration
 * @param options
 * @param fix whether to automatically fix the format
 */
function format(options, fix) {
    if (fix === void 0) { fix = false; }
    var program = lint_1.createProgram(options);
    var srcFiles = program.getSourceFiles()
        .map(function (sourceFile) { return sourceFile.fileName; })
        .filter(function (f) { return !f.endsWith('.d.ts'); });
    return fix ? fixFormat(srcFiles) : checkFormat(srcFiles);
}
exports.format = format;
/**
 * Runs clang-format to automatically fix the format of supplied files.
 *
 * @param srcFiles list of source files
 */
function fixFormat(srcFiles) {
    return new Promise(function (resolve, reject) {
        var args = baseArgs.concat(['-i'], srcFiles);
        clangFormat.spawnClangFormat(args, function (err) {
            if (err) {
                reject(err);
            }
            else {
                resolve(true);
            }
        }, 'inherit');
    });
}
/**
 * Runs clang-format on the list of files and checks whether they are formatted
 * correctly. Returns true if all files are formatted correctly.
 *
 * @param srcFiles list of source files
 */
function checkFormat(srcFiles) {
    return new Promise(function (resolve, reject) {
        var output = '';
        var args = baseArgs.concat(['-output-replacements-xml'], srcFiles);
        var out = clangFormat
            .spawnClangFormat(args, function (err) {
            if (err) {
                reject(err);
            }
        }, ['ignore', 'pipe', process.stderr])
            .stdout;
        out.setEncoding('utf8');
        out.on('data', function (data) {
            output += data;
        });
        out.on('end', function () {
            resolve(output.indexOf('<replacement ') === -1 ? true : false);
        });
    });
}
//# sourceMappingURL=format.js.map